#ifndef NT2_INCLUDE_FUNCTIONS_POW_ABS_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_POW_ABS_HPP_INCLUDED

#include <nt2/exponential/include/functions/pow_abs.hpp>

#endif
